==> kubernetes-model-core-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/CapabilitiesFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface CapabilitiesFluent<A extends CapabilitiesFluent<A>> extends Fluent<A>{
  public A addToAdd(Integer index,String item);
  public A setToAdd(Integer index,String item);
  public A addToAdd(java.lang.String... items);
  public A addAllToAdd(Collection<String> items);
  public A removeFromAdd(java.lang.String... items);
  public A removeAllFromAdd(Collection<String> items);
  public List<String> getAdd();
  public String getAdd(Integer index);
  public String getFirstAdd();
  public String getLastAdd();
  public String getMatchingAdd(Predicate<String> predicate);
  public Boolean hasMatchingAdd(Predicate<String> predicate);
  public A withAdd(List<String> add);
  public A withAdd(java.lang.String... add);
  public Boolean hasAdd();
  public A addToDrop(Integer index,String item);
  public A setToDrop(Integer index,String item);
  public A addToDrop(java.lang.String... items);
  public A addAllToDrop(Collection<String> items);
  public A removeFromDrop(java.lang.String... items);
  public A removeAllFromDrop(Collection<String> items);
  public List<String> getDrop();
  public String getDrop(Integer index);
  public String getFirstDrop();
  public String getLastDrop();
  public String getMatchingDrop(Predicate<String> predicate);
  public Boolean hasMatchingDrop(Predicate<String> predicate);
  public A withDrop(List<String> drop);
  public A withDrop(java.lang.String... drop);
  public Boolean hasDrop();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}

==> kubernetes-model-core-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/CapabilitiesFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CapabilitiesFluent<A extends CapabilitiesFluent<A>> extends Fluent<A>{
  public A addToAdd(int index,String item);
  public A setToAdd(int index,String item);
  public A addToAdd(java.lang.String... items);
  public A addAllToAdd(Collection<String> items);
  public A removeFromAdd(java.lang.String... items);
  public A removeAllFromAdd(Collection<String> items);
  public List<String> getAdd();
  public String getAdd(int index);
  public String getFirstAdd();
  public String getLastAdd();
  public String getMatchingAdd(Predicate<String> predicate);
  public Boolean hasMatchingAdd(Predicate<String> predicate);
  public A withAdd(List<String> add);
  public A withAdd(java.lang.String... add);
  public Boolean hasAdd();
  public A addToDrop(int index,String item);
  public A setToDrop(int index,String item);
  public A addToDrop(java.lang.String... items);
  public A addAllToDrop(Collection<String> items);
  public A removeFromDrop(java.lang.String... items);
  public A removeAllFromDrop(Collection<String> items);
  public List<String> getDrop();
  public String getDrop(int index);
  public String getFirstDrop();
  public String getLastDrop();
  public String getMatchingDrop(Predicate<String> predicate);
  public Boolean hasMatchingDrop(Predicate<String> predicate);
  public A withDrop(List<String> drop);
  public A withDrop(java.lang.String... drop);
  public Boolean hasDrop();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}
